//
//  ViewControllerInContainer.m
//  AppointmentOverlapTest
//
//  Created by Mattia Lancieri on 12/06/14.
//  Copyright (c) 2014 Developer Support. All rights reserved.
//

#import "ViewControllerInContainer.h"
#import "MBProgressHUD.h"

@implementation ThemeClass
-(CGFloat)fontSizeMax
{
    return 20;
}
-(CGFloat)fontSizeMin
{
    return 13.5;
}
-(NSString *)fontNameHeavy
{
    return @"HelveticaNeue-Bold";
}
@end

@interface ViewControllerInContainer ()  <IGCalendarAppointmentDataSource,IGCalendarViewDelegate>
{
    NSMutableArray *_appts;
    IGCalendarView *_calendar;
    NSMutableArray *_dataSources;
    ThemeClass *theme;
}
@end

@implementation ViewControllerInContainer


- (void)viewDidLoad
{
    [super viewDidLoad];

    _calendar = [[IGCalendarView alloc] init];
    
    _calendar.theme = theme = [[ThemeClass alloc] init];
    
    _calendar.minYear = 2014;
    _calendar.maxYear = 2014;
    _calendar.displayBackButton = NO;
    _calendar.displayTitleBar = YES;
    [_calendar navigateToDate:[NSDate date] forType:IGCalendarViewDisplayTypeMonth];
    _calendar.delegate = self;
    [_calendar setTranslatesAutoresizingMaskIntoConstraints:NO];
    [self.view addSubview:_calendar];
    
    //Constraints
    NSDictionary *views = NSDictionaryOfVariableBindings(_calendar);
    
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"H:|[_calendar]|" options:0 metrics:nil views:views]];
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"V:|[_calendar]|" options:0 metrics:nil views:views]];
    
    _dataSources = [[NSMutableArray alloc]init];
    [_dataSources addObject:self];
    _calendar.appointmentDataSources = _dataSources;
    
    [self updateData];
}
-(void)updateData
{
    [self.hud showAnimated:YES whileExecutingBlock:^{
        _appts = [self generateAppointments:30];
    } completionBlock:^{
        [_calendar invalidate];
    }];
}
- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
/*-(void)calendarView:(IGCalendarView *)calView asyncAppointmentRequest:(IGCalendarAppointmentRequest *)request ofType:(IGCalendarAppointmentRequestType)requestType
{
    [[[NSOperationQueue alloc]init] addOperation:[NSBlockOperation blockOperationWithBlock:^(void)
                                                  {
                                                      NSTimeInterval min = [request.start timeIntervalSince1970];
                                                      NSTimeInterval max = [request.end timeIntervalSince1970];
                                                      NSMutableArray* returnAppts = [[NSMutableArray alloc]init];
                                                      for(NSDictionary* appt in _appts)
                                                      {
                                                          NSDate* startTime = appt[@"start"];
                                                          NSTimeInterval current = [startTime timeIntervalSince1970];
                                                          if(current >= min && current <= max)
                                                          {
                                                              IGCalendarAppointment* calAppt = [[IGCalendarAppointment alloc]init];
                                                              calAppt.startTime = startTime;
                                                              calAppt.endTime = appt[@"end"];
                                                              calAppt.location = appt[@"location"];
                                                              calAppt.title = appt[@"title"];
                                                              [returnAppts addObject:calAppt];
                                                          }
                                                      }
                                                      [[NSOperationQueue mainQueue] addOperation: [NSBlockOperation blockOperationWithBlock:^(void)
                                                                                                   {
                                                                                                       NSArray* appts = [NSArray arrayWithArray:returnAppts];
                                                                                                       [request provideAppointments:appts];
                                                                                                   }]];
                                                  }]];
}*/

-(NSArray*)calendarView:(IGCalendarView *)calView appointmentsForStart:(NSDate*)start end:(NSDate*)end ofType:(IGCalendarAppointmentRequestType)requestType
{
    NSTimeInterval min = [start timeIntervalSince1970];
    NSTimeInterval max = [end timeIntervalSince1970];
    NSMutableArray* returnAppts = [[NSMutableArray alloc]init];
    for(NSDictionary* appt in _appts)
    {
        NSDate* startTime = appt[@"start"];
        NSTimeInterval current = [startTime timeIntervalSince1970];
        if(current >= min && current <= max)
        {
            IGCalendarAppointment* calAppt = [[IGCalendarAppointment alloc]init];
            calAppt.startTime = startTime;
            calAppt.endTime = appt[@"end"];
            calAppt.title = appt[@"title"];
            calAppt.recurrence = NO;
            calAppt.allDay = YES;
            
            [returnAppts addObject:calAppt];
        }
    }
    
    return returnAppts;
}

-(UIColor*)colorForAppointmentsInIGCalendarView:(IGCalendarView*)calView
{
    return [UIColor greenColor];
}
-(NSMutableArray *)generateAppointments:(int)count
{
    NSString *dateString, *month, *day, *year, *time, *location, *title;
    NSArray *titles = @[@"1", @"2", @"3", @"4"];
    NSMutableArray *appointments = [[NSMutableArray alloc] init];
    for (int j = 0; j < count; j++)
    {
        NSMutableDictionary *appointment = [[NSMutableDictionary alloc] init];
        month = [NSString stringWithFormat:@"%d", 6];
        day = [NSString stringWithFormat:@"%d", j+1];
        year = @"2014";
        time = [NSString stringWithFormat:@"%c%c:%c%c PM",
                arc4random_uniform(1) + 48,
                arc4random_uniform(9) + 48,
                arc4random_uniform(5) + 48,
                arc4random_uniform(9) + 48];
        title =[titles objectAtIndex:arc4random_uniform(titles.count)];
        NSDateFormatter *df = [[NSDateFormatter alloc] init];
        [df setDateFormat:@"MM-dd-yyyy hh:mm a"];
        dateString = [NSString stringWithFormat:@"%@-%@-%@ %@", month, day, year, time];
        NSDate *startDate = [df dateFromString: dateString];
        NSDate *endDate = [startDate dateByAddingTimeInterval:(60 * (arc4random_uniform(180) + 60))];
        [appointment setObject:startDate forKey:@"start"];
        [appointment setObject:endDate forKey:@"end"];
        [appointment setObject:title forKey:@"title"];
        [appointments addObject:appointment];
    }
    return appointments;
}
-(BOOL)calendarView:(IGCalendarView*)calView monthViewDayTapped:(NSDate*)date
{
    return NO;
}
-(NSString *)calendarView:(IGCalendarView *)calView titleLabelForDate:(NSDate *)date forDisplayType:(IGCalendarViewDisplayType)displayType
{
    NSDateFormatter *frmt = [[NSDateFormatter alloc] init];
    [frmt setDateFormat:@"MMMM yyyy"];
    
    return [frmt stringFromDate:date];
}

-(MBProgressHUD *)hud
{
    MBProgressHUD *HUD = [[MBProgressHUD alloc] initWithView:self.view];
    
    if (self.navigationController != nil)
    {
        [self.navigationController.view addSubview:HUD];
    }
    else
    {
        [self.view addSubview:HUD];
    }
    
    HUD.dimBackground = YES;
    
    HUD.labelText = @"Loading...";
    
    HUD.removeFromSuperViewOnHide = YES;
    
    return HUD;
}
@end
